@@ -12,7 +12,7 @@ use PerlX::Maybe qw( maybe provided );
 use Carp ();
 
 # ABSTRACT: WebSocket connection for AnyEvent
-our $VERSION = '0.42_01'; # TRIAL VERSION
+our $VERSION = '0.45_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -228,8 +228,7 @@ sub send
   
   if(ref $message)
   {
-    $frame = Protocol::WebSocket::Frame->new(buffer => $message->body, masked => $self->masked, max_payload_size => 0);
-    $frame->opcode($message->opcode);
+    $frame = Protocol::WebSocket::Frame->new(opcode => $message->opcode, buffer => $message->body, masked => $self->masked, max_payload_size => 0);
   }
   else
   {
@@ -249,7 +248,7 @@ sub _cancel_for
   return sub {
     my $accessor = "_${event}_cb";
     @{ $self->$accessor } = grep { Scalar::Util::refaddr($_) != $handler_id } 
-                         @{ $self->$accessor };
+                            @{ $self->$accessor };
   };
 }
 
@@ -328,7 +327,7 @@ AnyEvent::WebSocket::Connection - WebSocket connection for AnyEvent
 
 =head1 VERSION
 
-version 0.42_01
+version 0.45_01
 
 =head1 SYNOPSIS
 
